@@ -18,12 +18,13 @@
  */
 
 #include "osd.h"
-#include "utils.h"
+
 #include "kscreen_daemon_debug.h"
 
+#include "../common/utils.h"
+
 #include <KScreen/Mode>
 
-#include <QLoggingCategory>
 #include <QTimer>
 #include <QStandardPaths>
 #include <KDeclarative/QmlObjectSharedEngine>
